Learn R Programming

HGDMr (version 1.0.1)

vol2area_rating: Convert depressional storage volume to area

Description

Convert depressional storage volume to area

Usage

vol2area_rating(rating_curve, volumes, method = "linear")

Value

Returns a scalar or vector of lake stages

Arguments

rating_curve

Required. Data frame containing the variables area and volume.

volumes

A scalar or vector of depression storage volumes.

method

Method for interpolation. Default is linear. Alternatively, a spline can be fitted by specifying method = "spline" and any other options used by the function spline.

Author

Kevin Shook

Examples

Run this code
{
rating_curve <- data.frame(area=1:10, volume=seq(10, 100, 10))
a <- vol2area_rating(rating_curve, 55)
}

Run the code above in your browser using DataLab