Required. Data frame containing the variables area and volume.
volumes
A scalar or vector of depression storage volumes.
method
Method for interpolation. Default is linear. Alternatively,
a spline can be fitted by specifying method = "spline" and any other options used by the function spline.